@@ -51,6 +51,11 @@ void CountingHash::output_fasta_kmer_pos_freq(
     outfile.close();
 }
 
+const HashIntoType CountingHash::n_unique_kmers() const
+{
+    return _n_unique_kmers;
+}
+
 BoundedCounterType CountingHash::get_min_count(const std::string &s)
 {
     KMerIterator kmers(s.c_str(), _ksize);
@@ -107,7 +112,7 @@ CountingHash::abundance_distribution(
     // if not, could lead to overflow.
     if (sizeof(BoundedCounterType) != 2) {
         delete[] dist;
-        throw std::exception();
+        throw khmer_exception();
     }
 
     while(!parser->is_complete()) {
@@ -282,7 +287,7 @@ void CountingHash::get_kadian_count(
     }
 
     if (!counts.size()) {
-        throw std::exception();
+        throw khmer_exception();
     }
     unsigned int kpos = nk * _ksize;
 
@@ -635,10 +640,9 @@ CountingHashGzFileReader::CountingHashGzFileReader(
         HashIntoType kmer;
         BoundedCounterType count;
 
-        int read_k, read_c;
         for (HashIntoType n = 0; n < n_counts; n++) {
-            read_k = gzread(infile, (char *) &kmer, sizeof(kmer));
-            read_c = gzread(infile, (char *) &count, sizeof(count));
+            int read_k = gzread(infile, (char *) &kmer, sizeof(kmer));
+            int read_c = gzread(infile, (char *) &count, sizeof(count));
 
             if (read_k <= 0 || read_c <= 0) {
                 std::string err = "K-mer count read error: " + infilename;
@@ -658,7 +662,7 @@ CountingHashFileWriter::CountingHashFileWriter(
     const CountingHash  &ht)
 {
     if (!ht._counts[0]) {
-        throw std::exception();
+        throw khmer_exception();
     }
 
     unsigned int save_ksize = ht._ksize;
@@ -711,7 +715,7 @@ CountingHashGzFileWriter::CountingHashGzFileWriter(
     const CountingHash  &ht)
 {
     if (!ht._counts[0]) {
-        throw std::exception();
+        throw khmer_exception();
     }
 
     unsigned int save_ksize = ht._ksize;
