@@ -18,7 +18,7 @@
 #endif
 
 #include "read_parsers.hh"
-
+#include "khmer_exception.hh"
 
 namespace khmer
 {
@@ -103,26 +103,27 @@ accumulate_timer_deltas( uint32_t metrics_key )
 #endif
 
 IStreamReader::
-IStreamReader( )
+IStreamReader( int const fd )
     :
 #ifdef WITH_INTERNAL_METRICS
     pmetrics( StreamReaderPerformanceMetrics( ) ),
 #endif
     _alignment( 0 ),
     _max_aligned( SSIZE_MAX ),
-    _at_eos( false )
-{ }
+    _at_eos( false ),
+    _file_descriptor( fd )
+{
+    if (0 > fd) {
+        throw InvalidStreamBuffer( );
+    }
+}
 
 
 RawStreamReader::
 RawStreamReader( int const fd, size_t const alignment )
-    : IStreamReader( )
+    : IStreamReader( fd )
 {
 
-    if (0 > fd) {
-        throw InvalidStreamBuffer( );
-    }
-
 #ifdef __linux__
     if (alignment) {
         _alignment	= alignment;
@@ -130,19 +131,14 @@ RawStreamReader( int const fd, size_t const alignment )
     }
 #endif
 
-    _stream_handle    = fd;
-
 }
 
 
 GzStreamReader::
 GzStreamReader( int const fd )
-    : IStreamReader( )
+    : IStreamReader( fd )
 {
 
-    if (0 > fd) {
-        throw InvalidStreamBuffer( );
-    }
     _stream_handle    = gzdopen( fd, "rb" );
     if (NULL == _stream_handle) {
         throw InvalidStreamBuffer( );
@@ -153,12 +149,9 @@ GzStreamReader( int const fd )
 
 Bz2StreamReader::
 Bz2StreamReader( int const fd )
-    : IStreamReader( )
+    : IStreamReader( fd )
 {
 
-    if (0 > fd) {
-        throw InvalidStreamBuffer( );
-    }
     if (NULL == (_stream_handle = fdopen( fd, "r" ))) {
         throw InvalidStreamBuffer( );
     }
@@ -170,18 +163,19 @@ Bz2StreamReader( int const fd )
 
 IStreamReader::
 ~IStreamReader( )
-{ }
+{
+    if (0 > _file_descriptor) {
+        close( _file_descriptor);
+    }
+    _file_descriptor = -1;
+
+}
 
 
 RawStreamReader::
 ~RawStreamReader( )
 {
 
-    if (0 <= _stream_handle) {
-        close( _stream_handle );
-    }
-    _stream_handle = -1;
-
 }
 
 
@@ -246,10 +240,12 @@ read_into_cache( uint8_t * const cache, uint64_t const cache_size )
     ssize_t	nbread		    = 0;
     uint64_t	nbread_total	    = 0;
 
-    assert (NULL != cache);
     if (0 == cache_size) {
         return 0;
     }
+    if (!(NULL != cache)) {
+        throw khmer_exception();
+    }
 
 #ifdef __linux__
     if (_alignment && (0 != (cache_size % _alignment))) {
@@ -264,7 +260,7 @@ read_into_cache( uint8_t * const cache, uint64_t const cache_size )
 #endif
         nbread =
             read(
-                _stream_handle,
+                _file_descriptor,
                 cache + nbread_total,
                 (size_t)(nbrem > _max_aligned ? _max_aligned : nbrem )
             );
@@ -294,7 +290,9 @@ read_into_cache( uint8_t * const cache, uint64_t const cache_size )
     int		nbread		    = 0;
     uint64_t	nbread_total	    = 0;
 
-    assert (NULL != cache);
+    if (! (NULL != cache)) {
+        throw khmer_exception();
+    }
     if (0 == cache_size) {
         return 0;
     }
@@ -342,7 +340,9 @@ read_into_cache( uint8_t * const cache, uint64_t const cache_size )
     int		nbread		    = 0;
     uint64_t	nbread_total	    = 0;
 
-    assert (NULL != cache);
+    if (! (NULL != cache)) {
+        throw khmer_exception();
+    }
     if (0 == cache_size) {
         return 0;
     }
@@ -390,7 +390,7 @@ read_into_cache( uint8_t * const cache, uint64_t const cache_size )
             nbread_total += nbread;
             break;
 
-            // TODO: Inject BZ2 error code or error string into exception.
+        // TODO: Inject BZ2 error code or error string into exception.
         default:
             throw StreamReadError( );
 
@@ -881,7 +881,9 @@ CacheManager::
 _perform_segment_maintenance( CacheSegment &segment )
 {
 #if (0)
-    assert( segment.avail );
+    if (!( segment.avail )) {
+        throw khmer_exception();
+    }
 #endif
 
 #ifdef TRACE_STATE_CHANGES
@@ -1072,7 +1074,9 @@ _get_segment( bool const higher )
     uint32_t	    thread_id		= _thread_id_map.get_thread_id( );
     CacheSegment *  segment_PTR		= NULL;
 
-    assert( NULL != _segments );
+    if (!( NULL != _segments )) {
+        throw khmer_exception();
+    }
 
     // If referring to a segment to snoop,
     // then index is for the thread with the next higher ID.
@@ -1101,7 +1105,9 @@ void
 CacheManager::
 _fill_segment_from_stream( CacheSegment & segment )
 {
+#ifdef WITH_INTERNAL_METRICS
     uint64_t	nbfilled    = 0;
+#endif
 
     // Wait while segment not selected and not end of stream.
 #ifdef WITH_INTERNAL_METRICS
@@ -1150,12 +1156,15 @@ _fill_segment_from_stream( CacheSegment & segment )
 #ifdef WITH_INTERNAL_METRICS
         segment.pmetrics.start_timers( );
 #endif
+
         segment.size =
-            segment.cursor
-            +   (	nbfilled =
-                        _stream_reader.read_into_cache(
-                            segment.memory, _segment_size
-                        ));
+            segment.cursor + (
+#ifdef WITH_INTERNAL_METRICS
+                nbfilled =
+#endif
+                    _stream_reader.read_into_cache(
+                        segment.memory, _segment_size
+                    ));
 #ifdef WITH_INTERNAL_METRICS
         segment.pmetrics.stop_timers( );
 #endif
@@ -1402,8 +1411,7 @@ IParser(
         _states[ i ] = NULL;
     }
 
-    int regex_rc = -1;
-    regex_rc =
+    int regex_rc =
         regcomp(
             &_re_read_2_nosub,
             // ".+(/2| 2:[YN]:[[:digit:]]+:[[:alpha:]]+)$",
@@ -1411,7 +1419,7 @@ IParser(
             REG_EXTENDED | REG_NOSUB
         );
     if (regex_rc) {
-        throw std::exception();
+        throw khmer_exception();
     }
     regex_rc =
         regcomp(
@@ -1419,7 +1427,7 @@ IParser(
             "^.+(/1| 1:[YN]:[[:digit:]]+:[[:alpha:]]+).{0}", REG_EXTENDED
         );
     if (regex_rc) {
-        throw std::exception();
+        throw khmer_exception();
     }
     regex_rc =
         regcomp(
@@ -1427,7 +1435,7 @@ IParser(
             "^.+(/2| 2:[YN]:[[:digit:]]+:[[:alpha:]]+).{0}", REG_EXTENDED
         );
     if (regex_rc) {
-        throw std::exception();
+        throw khmer_exception();
     }
 }
 
