@@ -10,20 +10,6 @@
 
 using namespace std;
 
-int ScoringMatrix::assign(char b)
-{
-    if (b == 'A') {
-        return 0;
-    } else if (b == 'C') {
-        return 1;
-    } else if (b == 'G') {
-        return 2;
-    } else if (b == 'T') {
-        return 3;
-    }
-    return 4;
-}
-
 double ScoringMatrix::score(char ref, char qry)
 {
     //int r = assign(ref);
