@@ -20,6 +20,7 @@ import os
 import argparse
 import textwrap
 import khmer
+import sys
 from khmer.file import check_file_status, check_space
 from khmer.khmer_args import info
 
@@ -73,15 +74,16 @@ def main():
 
     check_space(filenames)
 
-    print 'loading partition map from:', partitionmap_file
+    print >>sys.stderr, 'loading partition map from:', partitionmap_file
     htable.load_partitionmap(partitionmap_file)
 
     for infile in filenames:
-        print 'outputting partitions for', infile
+        print >>sys.stderr, 'outputting partitions for', infile
         outfile = os.path.basename(infile) + '.part'
         part_count = htable.output_partitions(infile, outfile)
-        print 'output %d partitions for %s' % (part_count, infile)
-        print 'partitions are in', outfile
+        print >>sys.stderr, 'output %d partitions for %s' % (
+            part_count, infile)
+        print >>sys.stderr, 'partitions are in', outfile
 
 if __name__ == '__main__':
     main()
