@@ -22,7 +22,8 @@ import gc
 import os.path
 import os
 import textwrap
-from khmer.khmer_args import (build_hashbits_args, report_on_config, info)
+from khmer.khmer_args import (build_hashbits_args, report_on_config, info,
+                              add_threading_args)
 import glob
 from khmer.file import check_file_status, check_space
 
@@ -35,7 +36,7 @@ import re
 import platform
 if "Linux" == platform.system():
     def __debug_vm_usage(msg):
-        print "===> DEBUG: " + msg
+        print >>sys.stderr, "===> DEBUG: " + msg
         for vmstat in re.findall(r".*Vm.*", file("/proc/self/status").read()):
             print vmstat
 else:
@@ -48,22 +49,22 @@ def worker(queue, basename, stop_big_traversals):
         try:
             (htable, index, start, stop) = queue.get(False)
         except Queue.Empty:
-            print 'exiting'
+            print >>sys.stderr, 'exiting'
             return
 
         outfile = basename + '.subset.%d.pmap' % (index,)
         if os.path.exists(outfile):
-            print 'SKIPPING', outfile, ' -- already exists'
+            print >>sys.stderr, 'SKIPPING', outfile, ' -- already exists'
             continue
 
-        print 'starting:', basename, index
+        print >>sys.stderr, 'starting:', basename, index
 
         # pay attention to stoptags when partitioning; take command line
         # direction on whether or not to exhaustively traverse.
         subset = htable.do_subset_partition(start, stop, True,
                                             stop_big_traversals)
 
-        print 'saving:', basename, index
+        print >>sys.stderr, 'saving:', basename, index
         htable.save_subset_partitionmap(subset, outfile)
         del subset
         gc.collect()
@@ -83,15 +84,13 @@ def get_parser():
     parser = build_hashbits_args(
         descr='Load, partition, and annotate FAST[AQ] sequences',
         epilog=textwrap.dedent(epilog))
+    add_threading_args(parser)
     parser.add_argument('--subset-size', '-s', default=DEFAULT_SUBSET_SIZE,
                         dest='subset_size', type=float,
                         help='Set subset size (usually 1e5-1e6 is good)')
     parser.add_argument('--no-big-traverse', dest='no_big_traverse',
                         action='store_true', default=False,
                         help='Truncate graph joins at big traversals')
-    parser.add_argument('--threads', '-T', dest='n_threads',
-                        default=DEFAULT_N_THREADS,
-                        help='Number of simultaneous threads to execute')
     parser.add_argument('--keep-subsets', dest='remove_subsets',
                         default=True, action='store_false',
                         help='Keep individual subsets (default: False)')
@@ -113,25 +112,25 @@ def main():  # pylint: disable=too-many-locals,too-many-statements
 
     check_space(args.input_filenames)
 
-    print 'Saving k-mer presence table to %s' % args.graphbase
-    print 'Loading kmers from sequences in %s' % repr(args.input_filenames)
-
-    print '--'
-    print 'SUBSET SIZE', args.subset_size
-    print 'N THREADS', args.n_threads
-    print '--'
+    print >>sys.stderr, 'Saving k-mer presence table to %s' % args.graphbase
+    print >>sys.stderr, 'Loading kmers from sequences in %s' % \
+        repr(args.input_filenames)
+    print >>sys.stderr, '--'
+    print >>sys.stderr, 'SUBSET SIZE', args.subset_size
+    print >>sys.stderr, 'N THREADS', args.threads
+    print >>sys.stderr, '--'
 
     # load-graph
 
-    print 'making k-mer presence table'
+    print >>sys.stderr, 'making k-mer presence table'
     htable = khmer.new_hashbits(args.ksize, args.min_tablesize, args.n_tables)
 
     for _, filename in enumerate(args.input_filenames):
-        print 'consuming input', filename
+        print >>sys.stderr, 'consuming input', filename
         htable.consume_fasta_and_tag(filename)
 
     fp_rate = khmer.calc_expected_collisions(htable)
-    print 'fp rate estimated to be %1.3f' % fp_rate
+    print >>sys.stderr, 'fp rate estimated to be %1.3f' % fp_rate
     if fp_rate > 0.15:          # 0.18 is ACTUAL MAX. Do not change.
         print >> sys.stderr, "**"
         print >> sys.stderr, ("** ERROR: the graph structure is too small for"
@@ -145,9 +144,11 @@ def main():  # pylint: disable=too-many-locals,too-many-statements
     # do we want to exhaustively traverse the graph?
     stop_big_traversals = args.no_big_traverse
     if stop_big_traversals:
-        print '** This script brakes for lumps: stop_big_traversals is true.'
+        print >>sys.stderr, '** This script brakes for lumps: ', \
+                            'stop_big_traversals is true.'
     else:
-        print '** Traverse all the things: stop_big_traversals is false.'
+        print >>sys.stderr, '** Traverse all the things:', \
+                            ' stop_big_traversals is false.'
 
     #
     # now, partition!
@@ -167,60 +168,64 @@ def main():  # pylint: disable=too-many-locals,too-many-statements
         end = divvy[_ + 1]
         worker_q.put((htable, _, start, end))
 
-    print 'enqueued %d subset tasks' % n_subsets
+    print >>sys.stderr, 'enqueued %d subset tasks' % n_subsets
     open('%s.info' % args.graphbase, 'w').write('%d subsets total\n'
                                                 % (n_subsets))
 
-    if n_subsets < args.n_threads:
-        args.n_threads = n_subsets
+    if n_subsets < args.threads:
+        args.threads = n_subsets
 
     # start threads!
-    print 'starting %d threads' % args.n_threads
-    print '---'
+    print >>sys.stderr, 'starting %d threads' % args.threads
+    print >>sys.stderr, '---'
 
     threads = []
-    for _ in range(args.n_threads):
+    for _ in range(args.threads):
         cur_thread = threading.Thread(target=worker,
                                       args=(worker_q, args.graphbase,
                                             stop_big_traversals))
         threads.append(cur_thread)
         cur_thread.start()
 
-    print 'done starting threads'
+    assert threading.active_count() == args.threads + 1
+
+    print >>sys.stderr, 'done starting threads'
 
     # wait for threads
     for _ in threads:
         _.join()
 
-    print '---'
-    print 'done making subsets! see %s.subset.*.pmap' % (args.graphbase,)
+    print >>sys.stderr, '---'
+    print >>sys.stderr, 'done making subsets! see %s.subset.*.pmap' % \
+        (args.graphbase,)
 
     # merge-partitions
 
     pmap_files = glob.glob(args.graphbase + '.subset.*.pmap')
 
-    print 'loading %d pmap files (first one: %s)' % (len(pmap_files),
-                                                     pmap_files[0])
+    print >>sys.stderr, 'loading %d pmap files (first one: %s)' % \
+        (len(pmap_files), pmap_files[0])
 
     htable = khmer.new_hashbits(args.ksize, 1, 1)
 
     for pmap_file in pmap_files:
-        print 'merging', pmap_file
+        print >>sys.stderr, 'merging', pmap_file
         htable.merge_subset_from_disk(pmap_file)
 
     if args.remove_subsets:
-        print 'removing pmap files'
+        print >>sys.stderr, 'removing pmap files'
         for pmap_file in pmap_files:
             os.unlink(pmap_file)
 
     # annotate-partitions
 
     for infile in args.input_filenames:
-        print 'outputting partitions for', infile
+        print >>sys.stderr, 'outputting partitions for', infile
         outfile = os.path.basename(infile) + '.part'
         part_count = htable.output_partitions(infile, outfile)
-        print 'output %d partitions for %s' % (part_count, infile)
-        print 'partitions are in', outfile
+        print >>sys.stderr, 'output %d partitions for %s' % (
+            part_count, infile)
+        print >>sys.stderr, 'partitions are in', outfile
 
 if __name__ == '__main__':
     main()
