@@ -54,6 +54,11 @@ def get_parser():
         merge-partitions.py -k 20 example
         annotate-partitions.py -k 20 example tests/test-data/random-20-a.fa
         extract-partitions.py example random-20-a.fa.part
+
+        (extract-partitions.py will produce a partition size distribution
+        in <base>.dist. The columns are: (1) number of reads, (2) count
+        of partitions with n reads, (3) cumulative sum of partitions,
+        (4) cumulative sum of reads.)
     """
     parser = argparse.ArgumentParser(
         description="Separate sequences that are annotated with partitions "
@@ -93,20 +98,24 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
 
     check_space(args.part_filenames)
 
-    print '---'
-    print 'reading partitioned files:', repr(args.part_filenames)
+    print >>sys.stderr, '---'
+    print >>sys.stderr, 'reading partitioned files:', repr(args.part_filenames)
     if args.output_groups:
-        print 'outputting to files named "%s.groupN.fa"' % args.prefix
-        print 'min reads to keep a partition:', args.min_part_size
-        print 'max size of a group file:', args.max_size
+        print >>sys.stderr, 'outputting to files named "%s.groupN.fa"' % \
+            args.prefix
+        print >>sys.stderr, 'min reads to keep a partition:', \
+            args.min_part_size
+        print >>sys.stderr, 'max size of a group file:', args.max_size
     else:
-        print 'NOT outputting groups! Beware!'
+        print >>sys.stderr, 'NOT outputting groups! Beware!'
 
     if args.output_unassigned:
-        print 'outputting unassigned reads to "%s.unassigned.fa"' % args.prefix
-
-    print 'partition size distribution will go to %s' % distfilename
-    print '---'
+        print >>sys.stderr, \
+            'outputting unassigned reads to "%s.unassigned.fa"' % \
+            args.prefix
+    print >>sys.stderr, 'partition size distribution will go to %s' \
+        % distfilename
+    print >>sys.stderr, '---'
 
     #
 
@@ -137,7 +146,7 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
     for filename in args.part_filenames:
         for index, read, pid in read_partition_file(filename):
             if index % 100000 == 0:
-                print '...', index
+                print >>sys.stderr, '...', index
 
             count[pid] = count.get(pid, 0) + 1
 
@@ -200,9 +209,9 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
             # print 'group_d', partition_id, group_n
         group_n += 1
 
-    print '%d groups' % group_n
+    print >>sys.stderr, '%d groups' % group_n
     if group_n == 0:
-        print 'nothing to output; exiting!'
+        print >>sys.stderr, 'nothing to output; exiting!'
         return
 
     # open a bunch of output files for the different groups
@@ -220,7 +229,7 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
         for index, read, partition_id in read_partition_file(filename):
             total_seqs += 1
             if index % 100000 == 0:
-                print '...x2', index
+                print >>sys.stderr, '...x2', index
 
             if partition_id == 0:
                 continue
@@ -237,16 +246,20 @@ def main():  # pylint: disable=too-many-locals,too-many-branches
             outfp.write(output_single(read))
             part_seqs += 1
 
-    print '---'
-    print 'Of %d total seqs,' % total_seqs
-    print 'extracted %d partitioned seqs into group files,' % part_seqs
-    print 'discarded %d sequences from small partitions (see -m),' % \
+    print >>sys.stderr, '---'
+    print >>sys.stderr, 'Of %d total seqs,' % total_seqs
+    print >>sys.stderr, 'extracted %d partitioned seqs into group files,' % \
+        part_seqs
+    print >>sys.stderr, \
+        'discarded %d sequences from small partitions (see -m),' % \
         toosmall_parts
-    print 'and found %d unpartitioned sequences (see -U).' % n_unassigned
-    print ''
-    print 'Created %d group files named %s.groupXXXX.%s' % (len(group_fps),
-                                                            args.prefix,
-                                                            suffix)
+    print >>sys.stderr, 'and found %d unpartitioned sequences (see -U).' % \
+        n_unassigned
+    print >>sys.stderr, ''
+    print >>sys.stderr, 'Created %d group files named %s.groupXXXX.%s' % \
+        (len(group_fps),
+         args.prefix,
+         suffix)
 
 if __name__ == '__main__':
     main()
