@@ -17,9 +17,12 @@ Use '-h' for parameter help.
 import os
 import khmer
 import textwrap
+import argparse
+import sys
 from khmer.thread_utils import ThreadedSequenceProcessor, verbose_loader
-from khmer.khmer_args import (build_counting_args, add_threading_args, info)
+from khmer.khmer_args import (ComboFormatter, add_threading_args, info)
 from khmer.file import check_file_status, check_space
+from khmer import __version__
 #
 
 DEFAULT_NORMALIZE_LIMIT = 20
@@ -37,11 +40,12 @@ def get_parser():
         load-into-counting.py -k 20 -x 5e7 table.kh data/100k-filtered.fa
         filter-abund.py -C 2 table.kh data/100k-filtered.fa
     """
-    parser = build_counting_args(
-        descr='Trim sequences at a minimum k-mer abundance.',
-        epilog=textwrap.dedent(epilog))
-    parser.add_argument('input_table', metavar='input_presence_table_filename',
-                        help='The input k-mer presence table filename')
+    parser = argparse.ArgumentParser(
+        description='Trim sequences at a minimum k-mer abundance.',
+        epilog=textwrap.dedent(epilog),
+        formatter_class=ComboFormatter)
+    parser.add_argument('input_table', metavar='input_counting_table_filename',
+                        help='The input k-mer counting table filename')
     parser.add_argument('input_filename', metavar='input_sequence_filename',
                         help='Input FAST[AQ] sequence filename', nargs='+')
     add_threading_args(parser)
@@ -61,6 +65,8 @@ def get_parser():
                         help='Output the trimmed sequences into a single file '
                         'with the given filename instead of creating a new '
                         'file for each input file.')
+    parser.add_argument('--version', action='version',
+                        version='khmer {v}'.format(v=__version__))
     return parser
 
 
@@ -76,11 +82,11 @@ def main():
 
     check_space(infiles)
 
-    print 'loading hashtable'
+    print >>sys.stderr, 'loading hashtable'
     htable = khmer.load_counting_hash(counting_ht)
     ksize = htable.ksize()
 
-    print "K:", ksize
+    print >>sys.stderr, "K:", ksize
 
     # the filtering function.
     def process_fn(record):
@@ -103,7 +109,7 @@ def main():
 
     # the filtering loop
     for infile in infiles:
-        print 'filtering', infile
+        print >>sys.stderr, 'filtering', infile
         if args.single_output_filename != '':
             outfile = args.single_output_filename
             outfp = open(outfile, 'a')
@@ -114,7 +120,7 @@ def main():
         tsp = ThreadedSequenceProcessor(process_fn, n_workers=args.threads)
         tsp.start(verbose_loader(infile), outfp)
 
-        print 'output in', outfile
+        print >>sys.stderr, 'output in', outfile
 
 if __name__ == '__main__':
     main()
