@@ -12,6 +12,7 @@ Find an initial set of highly connected k-mers, to save on repartitioning time.
 % python scripts/make-initial-stoptags.py <base>
 """
 
+import sys
 import textwrap
 import khmer
 from khmer.khmer_args import (build_counting_args, info)
@@ -65,6 +66,7 @@ def get_parser():
 
 
 def main():
+
     info('make-initial-stoptags.py', ['graph'])
     args = get_parser().parse_args()
 
@@ -79,15 +81,15 @@ def main():
 
     check_space(infiles)
 
-    print 'loading htable %s.pt' % graphbase
+    print >>sys.stderr, 'loading htable %s.pt' % graphbase
     htable = khmer.load_hashbits(graphbase + '.pt')
 
     # do we want to load stop tags, and do they exist?
     if args.stoptags:
-        print 'loading stoptags from', args.stoptags
+        print >>sys.stderr, 'loading stoptags from', args.stoptags
         htable.load_stop_tags(args.stoptags)
 
-    print 'loading tagset %s.tagset...' % graphbase
+    print >>sys.stderr, 'loading tagset %s.tagset...' % graphbase
     htable.load_tagset(graphbase + '.tagset')
 
     ksize = htable.ksize()
@@ -104,18 +106,19 @@ def main():
         start, end = divvy[:2]
 
     # partition!
-    print 'doing pre-partitioning from', start, 'to', end
+    print >>sys.stderr, 'doing pre-partitioning from', start, 'to', end
     subset = htable.do_subset_partition(start, end)
 
     # now, repartition...
-    print 'repartitioning to find HCKs.'
+    print >>sys.stderr, 'repartitioning to find HCKs.'
     htable.repartition_largest_partition(subset, counting,
                                          EXCURSION_DISTANCE,
                                          EXCURSION_KMER_THRESHOLD,
                                          EXCURSION_KMER_COUNT_THRESHOLD)
 
-    print 'saving stop tags'
+    print >>sys.stderr, 'saving stop tags'
     htable.save_stop_tags(graphbase + '.stoptags')
+    print >> sys.stderr, 'wrote to:', graphbase + '.stoptags'
 
 if __name__ == '__main__':
     main()
