@@ -65,10 +65,11 @@ def normalize_by_median(input_filename, outfp, htable, args, report_fp=None):
     for index, batch in enumerate(batchwise(screed.open(
             input_filename), batch_size)):
         if index > 0 and index % 100000 == 0:
-            print '... kept {kept} of {total} or {perc:2}%'.format(
-                kept=total - discarded, total=total,
-                perc=int(100. - discarded / float(total) * 100.))
-            print '... in file', input_filename
+            print >>sys.stderr, '... kept {kept} of {total} or'\
+                ' {perc:2}%'.format(kept=total - discarded, total=total,
+                                    perc=int(100. - discarded /
+                                             float(total) * 100.))
+            print >>sys.stderr, '... in file', input_filename
 
             if report_fp:
                 print >> report_fp, total, total - discarded, \
@@ -115,6 +116,11 @@ def normalize_by_median(input_filename, outfp, htable, args, report_fp=None):
         else:
             discarded += batch_size
 
+    if report_fp:
+        print >> report_fp, total, total - discarded, \
+            1. - (discarded / float(total))
+        report_fp.flush()
+
     return total, discarded
 
 
@@ -233,6 +239,7 @@ def main():  # pylint: disable=too-many-branches,too-many-statements
 
     total = 0
     discarded = 0
+    input_filename = None
 
     for index, input_filename in enumerate(args.input_filenames):
         if args.single_output_filename != '':
@@ -283,8 +290,8 @@ def main():  # pylint: disable=too-many-branches,too-many-statements
             htable.save(hashname)
 
     if args.report_total_kmers:
-        print >> sys.stderr, 'Total number of k-mers: {0}'.format(
-            htable.n_occupied())
+        print >> sys.stderr, 'Total number of unique k-mers: {0}'.format(
+            htable.n_unique_kmers())
 
     if args.savetable:
         print 'Saving k-mer counting table through', input_filename
