@@ -19,7 +19,7 @@ from nose.plugins.attrib import attr
 def test_fakelump_together():
     fakelump_fa = utils.get_test_data('fakelump.fa')
 
-    ht = khmer.new_hashbits(32, 1e7, 4)
+    ht = khmer.new_hashbits(32, 1e5, 4)
     ht.consume_fasta_and_tag(fakelump_fa)
 
     subset = ht.do_subset_partition(0, 0)
@@ -36,7 +36,7 @@ def test_fakelump_stop():
     fakelump_fa = utils.get_test_data('fakelump.fa')
     fakelump_stoptags_txt = utils.get_test_data('fakelump.fa.stoptags.txt')
 
-    ht = khmer.new_hashbits(32, 1e7, 4)
+    ht = khmer.new_hashbits(32, 1e5, 4)
     ht.consume_fasta_and_tag(fakelump_fa)
 
     for line in open(fakelump_stoptags_txt):
@@ -55,7 +55,7 @@ def test_fakelump_stop():
 def test_fakelump_stop2():
     fakelump_fa = utils.get_test_data('fakelump.fa')
 
-    ht = khmer.new_hashbits(32, 1e7, 4)
+    ht = khmer.new_hashbits(32, 1e5, 4)
     ht.consume_fasta_and_tag(fakelump_fa)
 
     ht.add_stop_tag('GGGGAGGGGTGCAGTTGTGACTTGCTCGAGAG')
@@ -74,7 +74,7 @@ def test_fakelump_repartitioning():
     fakelump_fa = utils.get_test_data('fakelump.fa')
     fakelump_fa_foo = utils.get_temp_filename('fakelump.fa.stopfoo')
 
-    ht = khmer.new_hashbits(32, 1e7, 4)
+    ht = khmer.new_hashbits(32, 1e5, 4)
     ht.consume_fasta_and_tag(fakelump_fa)
 
     subset = ht.do_subset_partition(0, 0)
@@ -91,7 +91,7 @@ def test_fakelump_repartitioning():
     EXCURSION_DISTANCE = 40
     EXCURSION_KMER_THRESHOLD = 82
     EXCURSION_KMER_COUNT_THRESHOLD = 1
-    counting = khmer.new_counting_hash(32, 1e7, 4)
+    counting = khmer.new_counting_hash(32, 1e4, 4)
 
     ht.repartition_largest_partition(None, counting,
                                      EXCURSION_DISTANCE,
@@ -102,7 +102,7 @@ def test_fakelump_repartitioning():
 
     # ok, now re-do everything with these stop tags, specifically.
 
-    ht = khmer.new_hashbits(32, 1e7, 4)
+    ht = khmer.new_hashbits(32, 1e5, 4)
     ht.consume_fasta_and_tag(fakelump_fa)
     ht.load_stop_tags(fakelump_fa_foo)
 
@@ -118,7 +118,7 @@ def test_fakelump_load_stop_tags_trunc():
     fakelump_fa = utils.get_test_data('fakelump.fa')
     fakelump_fa_foo = utils.get_temp_filename('fakelump.fa.stopfoo')
 
-    ht = khmer.new_hashbits(32, 1e7, 4)
+    ht = khmer.new_hashbits(32, 1e5, 4)
     ht.consume_fasta_and_tag(fakelump_fa)
 
     subset = ht.do_subset_partition(0, 0)
@@ -135,7 +135,7 @@ def test_fakelump_load_stop_tags_trunc():
     EXCURSION_DISTANCE = 40
     EXCURSION_KMER_THRESHOLD = 82
     EXCURSION_KMER_COUNT_THRESHOLD = 1
-    counting = khmer.new_counting_hash(32, 1e7, 4)
+    counting = khmer.new_counting_hash(32, 4, 4)
 
     ht.repartition_largest_partition(None, counting,
                                      EXCURSION_DISTANCE,
@@ -150,7 +150,7 @@ def test_fakelump_load_stop_tags_trunc():
     fp.close()
 
     # ok, now try loading these stop tags; should fail.
-    ht = khmer.new_hashbits(32, 1e7, 4)
+    ht = khmer.new_hashbits(32, 4, 4)
     ht.consume_fasta_and_tag(fakelump_fa)
 
     try:
@@ -165,7 +165,7 @@ def test_fakelump_load_stop_tags_notexist():
     fakelump_fa_foo = utils.get_temp_filename('fakelump.fa.stopfoo')
 
     # ok, now try loading these stop tags; should fail.
-    ht = khmer.new_hashbits(32, 1e7, 4)
+    ht = khmer.new_hashbits(32, 4, 4)
 
     try:
         ht.load_stop_tags(fakelump_fa_foo)
