@@ -7,11 +7,17 @@
 
 # pylint: disable=C0111,C0103,E1103,W0612
 
+import json
 import sys
 import os
 import shutil
 from cStringIO import StringIO
 import traceback
+from nose.plugins.attrib import attr
+import subprocess
+import threading
+import bz2
+import io
 
 import khmer_tst_utils as utils
 import khmer
@@ -27,72 +33,6 @@ def teardown():
     utils.cleanup()
 
 
-def _runscript(scriptname):
-    import pkg_resources
-    ns = {"__name__": "__main__"}
-    ns['sys'] = globals()['sys']
-    try:
-        pkg_resources.get_distribution("khmer").run_script(
-            scriptname, ns)
-        return 0
-    except pkg_resources.ResolutionError, err:
-        paths = [os.path.join(os.path.dirname(__file__),
-                              "../scripts")]
-        paths.extend(os.environ['PATH'].split(':'))
-        for path in paths:
-            scriptfile = os.path.join(path, scriptname)
-            if os.path.isfile(scriptfile):
-                execfile(scriptfile, ns)
-                return 0
-    return -1
-
-
-def runscript(scriptname, args, in_directory=None, fail_ok=False):
-    """
-    Run the given Python script, with the given args, in the given directory,
-    using 'execfile'.
-    """
-    sysargs = [scriptname]
-    sysargs.extend(args)
-
-    cwd = os.getcwd()
-
-    try:
-        status = -1
-        oldargs = sys.argv
-        sys.argv = sysargs
-
-        oldout, olderr = sys.stdout, sys.stderr
-        sys.stdout = StringIO()
-        sys.stderr = StringIO()
-
-        if in_directory:
-            os.chdir(in_directory)
-
-        try:
-            print 'running:', scriptname, 'in:', in_directory
-            print 'arguments', sysargs
-            status = _runscript(scriptname)
-        except SystemExit, e:
-            status = e.code
-        except:
-            traceback.print_exc(file=sys.stderr)
-            status = -1
-    finally:
-        sys.argv = oldargs
-        out, err = sys.stdout.getvalue(), sys.stderr.getvalue()
-        sys.stdout, sys.stderr = oldout, olderr
-
-        os.chdir(cwd)
-
-    if status != 0 and not fail_ok:
-        print out
-        print err
-        assert False, (status, out, err)
-
-    return status, out, err
-
-
 def test_check_space():
     # @CTB this probably belongs in a new test file, along with other
     # tests of the file.py module.
@@ -108,8 +48,8 @@ def test_load_into_counting():
 
     args.extend([outfile, infile])
 
-    (status, out, err) = runscript(script, args)
-    assert 'Total number of k-mers: 95' in err, err
+    (status, out, err) = utils.runscript(script, args)
+    assert 'Total number of unique k-mers: 95' in err, err
     assert os.path.exists(outfile)
 
 
@@ -122,11 +62,76 @@ def test_load_into_counting_fail():
 
     args.extend([outfile, infile])
 
-    (status, out, err) = runscript(script, args, fail_ok=True)
+    (status, out, err) = utils.runscript(script, args, fail_ok=True)
     assert status == 1, status
     assert "ERROR:" in err
 
 
+def test_load_into_counting_tsv():
+    script = scriptpath('load-into-counting.py')
+    args = ['-x', '1e7', '-N', '2', '-k', '20', '-t', '-s', 'tsv']
+
+    outfile = utils.get_temp_filename('out.kh')
+    tabfile = outfile + '.info.tsv'
+    infile = utils.get_test_data('test-abund-read-2.fa')
+
+    args.extend([outfile, infile])
+
+    (status, out, err) = utils.runscript(script, args)
+    assert 'Total number of unique k-mers: 95' in err, err
+    assert os.path.exists(outfile)
+    assert os.path.exists(tabfile)
+    with open(tabfile) as tabfh:
+        tabfile_lines = tabfh.readlines()
+    assert len(tabfile_lines) == 2
+    outbase = os.path.basename(outfile)
+    expected_tsv_line = '\t'.join([outbase, '0.000', '95', infile]) + '\n'
+    assert tabfile_lines[1] == expected_tsv_line, tabfile_lines
+
+
+def test_load_into_counting_json():
+    script = scriptpath('load-into-counting.py')
+    args = ['-x', '1e7', '-N', '2', '-k', '20', '-t', '-s', 'json']
+
+    outfile = utils.get_temp_filename('out.kh')
+    jsonfile = outfile + '.info.json'
+    infile = utils.get_test_data('test-abund-read-2.fa')
+
+    args.extend([outfile, infile])
+
+    (status, out, err) = utils.runscript(script, args)
+    assert 'Total number of unique k-mers: 95' in err, err
+    assert os.path.exists(outfile)
+    assert os.path.exists(jsonfile)
+
+    with open(jsonfile) as jsonfh:
+        got_json = json.load(jsonfh)
+    outbase = os.path.basename(outfile)
+    expected_json = {
+        "files": [infile],
+        "ht_name": outbase,
+        "num_kmers": 95,
+        "fpr": 9.024965705097741e-11,
+        "mrinfo_version": "0.1.0",
+    }
+
+    assert got_json == expected_json, got_json
+
+
+def test_load_into_counting_bad_summary_fmt():
+    script = scriptpath('load-into-counting.py')
+    args = ['-x', '1e7', '-N', '2', '-k', '20', '-s', 'badfmt']
+
+    outfile = utils.get_temp_filename('out.kh')
+    infile = utils.get_test_data('test-abund-read-2.fa')
+
+    args.extend([outfile, infile])
+
+    (status, out, err) = utils.runscript(script, args, fail_ok=True)
+    assert status != 0, status
+    assert "invalid choice: 'badfmt'" in err, err
+
+
 def _make_counting(infilename, SIZE=1e7, N=2, K=20, BIGCOUNT=True):
     script = scriptpath('load-into-counting.py')
     args = ['-x', str(SIZE), '-N', str(N), '-k', str(K)]
@@ -138,7 +143,7 @@ def _make_counting(infilename, SIZE=1e7, N=2, K=20, BIGCOUNT=True):
 
     args.extend([outfile, infilename])
 
-    runscript(script, args)
+    utils.runscript(script, args)
     assert os.path.exists(outfile)
 
     return outfile
@@ -153,7 +158,7 @@ def test_filter_abund_1():
 
     script = scriptpath('filter-abund.py')
     args = [counting_ht, infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
@@ -172,7 +177,7 @@ def test_filter_abund_2():
 
     script = scriptpath('filter-abund.py')
     args = ['-C', '1', counting_ht, infile, infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
@@ -193,7 +198,7 @@ def test_filter_abund_3_fq_retained():
 
     script = scriptpath('filter-abund.py')
     args = ['-C', '1', counting_ht, infile, infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
@@ -216,9 +221,9 @@ def test_filter_abund_1_singlefile():
 
     script = scriptpath('filter-abund-single.py')
     args = ['-x', '1e7', '-N', '2', '-k', '17', '-t', infile]
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
 
-    assert 'Total number of k-mers: 98' in err, err
+    assert 'Total number of unique k-mers: 98' in err, err
 
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
@@ -239,7 +244,7 @@ def test_filter_abund_4_retain_low_abund():
 
     script = scriptpath('filter-abund.py')
     args = ['-V', counting_ht, infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
@@ -260,7 +265,7 @@ def test_filter_abund_5_trim_high_abund():
 
     script = scriptpath('filter-abund.py')
     args = ['-V', counting_ht, infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
@@ -283,7 +288,7 @@ def test_filter_abund_6_trim_high_abund_Z():
 
     script = scriptpath('filter-abund.py')
     args = ['-V', '-Z', '25', counting_ht, infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.abundfilt'
     assert os.path.exists(outfile), outfile
@@ -315,7 +320,7 @@ def test_filter_stoptags():
     # finally, run filter-stoptags.
     script = scriptpath('filter-stoptags.py')
     args = ['-k', str(K), stopfile, infile, infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     # verify that the basic output file exists
     outfile = infile + '.stopfilt'
@@ -328,6 +333,17 @@ def test_filter_stoptags():
     assert 'GGTTGACGGGGCTCAGGG' in seqs, seqs
 
 
+def test_normalize_by_median_indent():
+    infile = utils.get_test_data('paired-mixed.fa.pe')
+    hashfile = utils.get_test_data('normC20k20.kh')
+    outfile = utils.get_temp_filename('paired-mixed.fa.pe.keep')
+    script = scriptpath('normalize-by-median.py')
+    args = ['--loadtable', hashfile, '-o', outfile, infile]
+    (status, out, err) = utils.runscript(script, args)
+    assert status == 0, (out, err)
+    assert os.path.exists(outfile)
+
+
 def test_normalize_by_median():
     CUTOFF = '1'
 
@@ -338,9 +354,9 @@ def test_normalize_by_median():
 
     script = scriptpath('normalize-by-median.py')
     args = ['-C', CUTOFF, '-k', '17', '-t', infile]
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
 
-    assert 'Total number of k-mers: 98' in err, err
+    assert 'Total number of unique k-mers: 98' in err, err
 
     outfile = infile + '.keep'
     assert os.path.exists(outfile), outfile
@@ -353,7 +369,7 @@ def test_normalize_by_median():
 def test_normalize_by_median_version():
     script = scriptpath('normalize-by-median.py')
     args = ['--version']
-    status, out, err = runscript(script, args)
+    status, out, err = utils.runscript(script, args)
 
     errlines = err.splitlines()
     for err in errlines:
@@ -378,7 +394,7 @@ def test_normalize_by_median_2():
 
     script = scriptpath('normalize-by-median.py')
     args = ['-C', CUTOFF, '-k', '17', infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.keep'
     assert os.path.exists(outfile), outfile
@@ -399,7 +415,7 @@ def test_normalize_by_median_paired():
 
     script = scriptpath('normalize-by-median.py')
     args = ['-C', CUTOFF, '-p', '-k', '17', infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.keep'
     assert os.path.exists(outfile), outfile
@@ -420,7 +436,7 @@ def test_normalize_by_median_impaired():
 
     script = scriptpath('normalize-by-median.py')
     args = ['-C', CUTOFF, '-p', '-k', '17', infile]
-    runscript(script, args, in_dir, fail_ok=True)
+    utils.runscript(script, args, in_dir, fail_ok=True)
 
 
 def test_normalize_by_median_force():
@@ -439,7 +455,7 @@ def test_normalize_by_median_force():
     script = scriptpath('normalize-by-median.py')
     args = ['-f', '-C', CUTOFF, '-k', '17', corrupt_infile, good_infile]
 
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
 
     test_ht = khmer.load_counting_hash(corrupt_infile + '.ct.failed')
     test_good_read = 'CAGGCGCCCACCACCGTGCCCTCCAACCTGATGGT'
@@ -463,9 +479,9 @@ def test_normalize_by_median_no_bigcount():
     script = scriptpath('normalize-by-median.py')
     args = ['-C', '1000', '-k 8', '--savetable', hashfile, infile]
 
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
     assert status == 0, (out, err)
-    print (out, err)
+    print(out, err)
 
     assert os.path.exists(hashfile), hashfile
     kh = khmer.load_counting_hash(hashfile)
@@ -489,7 +505,7 @@ def test_normalize_by_median_dumpfrequency():
     args = ['-d', '2', '-C', CUTOFF, '-k', '17']
     args.extend(infiles)
 
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
 
     test_ht = khmer.load_counting_hash(os.path.join(in_dir, 'backup.ct'))
     test_good_read = 'CAGGCGCCCACCACCGTGCCCTCCAACCTGATGGT'
@@ -512,12 +528,29 @@ def test_normalize_by_median_empty():
 
     script = scriptpath('normalize-by-median.py')
     args = ['-C', CUTOFF, '-k', '17', infile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.keep'
     assert os.path.exists(outfile), outfile
 
 
+def test_normalize_by_median_fpr():
+    MIN_TABLESIZE_PARAM = 1
+
+    infile = utils.get_temp_filename('test-fpr.fq')
+    in_dir = os.path.dirname(infile)
+    shutil.copyfile(utils.get_test_data('test-fastq-reads.fq'), infile)
+
+    script = scriptpath('normalize-by-median.py')
+    args = ['-f', '-k 17', '-x ' + str(MIN_TABLESIZE_PARAM), infile]
+
+    (status, out, err) = utils.runscript(script, args, in_dir, fail_ok=True)
+
+    assert os.path.exists(infile + '.keep')
+    assert 'fp rate estimated to be' in out, out
+    assert '** ERROR: the k-mer counting table is too small' in err, err
+
+
 def test_count_median():
     infile = utils.get_temp_filename('test.fa')
     outfile = infile + '.counts'
@@ -527,7 +560,7 @@ def test_count_median():
 
     script = scriptpath('count-median.py')
     args = [counting_ht, infile, outfile]
-    runscript(script, args)
+    utils.runscript(script, args)
 
     assert os.path.exists(outfile), outfile
 
@@ -549,9 +582,9 @@ def test_load_graph():
 
     args.extend([outfile, infile])
 
-    (status, out, err) = runscript(script, args)
+    (status, out, err) = utils.runscript(script, args)
 
-    assert 'Total number of k-mers: 3959' in err, err
+    assert 'Total number of unique k-mers: 3960' in err, err
 
     ht_file = outfile + '.pt'
     assert os.path.exists(ht_file), ht_file
@@ -579,7 +612,7 @@ def test_load_graph_no_tags():
 
     args.extend([outfile, infile])
 
-    runscript(script, args)
+    utils.runscript(script, args)
 
     ht_file = outfile + '.pt'
     assert os.path.exists(ht_file), ht_file
@@ -602,11 +635,44 @@ def test_load_graph_fail():
 
     args.extend([outfile, infile])
 
-    (status, out, err) = runscript(script, args, fail_ok=True)
+    (status, out, err) = utils.runscript(script, args, fail_ok=True)
     assert status == 1, status
     assert "ERROR:" in err
 
 
+def test_load_graph_write_fp():
+    script = scriptpath('load-graph.py')
+    args = ['-x', '1e5', '-N', '2', '-k', '20', '-w']  # use small HT
+
+    outfile = utils.get_temp_filename('out')
+    infile = utils.get_test_data('random-20-a.fa')
+
+    args.extend([outfile, infile])
+
+    (status, out, err) = utils.runscript(script, args)
+
+    ht_file = outfile + '.pt'
+    assert os.path.exists(ht_file), ht_file
+
+    info_file = outfile + '.info'
+    assert os.path.exists(info_file), info_file
+    data = [x.strip() for x in open(info_file)]
+    data = set(data)
+    assert '3959 unique k-mers' in data
+    assert 'false positive rate estimated to be 0.002' in data
+
+
+def test_load_graph_multithread():
+    script = scriptpath('load-graph.py')
+
+    outfile = utils.get_temp_filename('test')
+    infile = utils.get_test_data('test-reads.fa')
+
+    args = ['-N', '4', '-x', '1e9', '-T', '8', outfile, infile]
+
+    (status, out, err) = utils.runscript(script, args)
+
+
 def _make_graph(infilename, min_hashsize=1e7, n_hashes=2, ksize=20,
                 do_partition=False,
                 annotate_partitions=False,
@@ -619,7 +685,7 @@ def _make_graph(infilename, min_hashsize=1e7, n_hashes=2, ksize=20,
 
     args.extend([outfile, infile])
 
-    runscript(script, args)
+    utils.runscript(script, args)
 
     ht_file = outfile + '.pt'
     assert os.path.exists(ht_file), ht_file
@@ -632,11 +698,11 @@ def _make_graph(infilename, min_hashsize=1e7, n_hashes=2, ksize=20,
         args = [outfile]
         if stop_big_traverse:
             args.insert(0, '--no-big-traverse')
-        runscript(script, args)
+        utils.runscript(script, args)
 
         script = scriptpath('merge-partitions.py')
         args = [outfile, '-k', str(ksize)]
-        runscript(script, args)
+        utils.runscript(script, args)
 
         final_pmap_file = outfile + '.pmap.merged'
         assert os.path.exists(final_pmap_file)
@@ -646,7 +712,7 @@ def _make_graph(infilename, min_hashsize=1e7, n_hashes=2, ksize=20,
             args = ["-k", str(ksize), outfile, infilename]
 
             in_dir = os.path.dirname(outfile)
-            runscript(script, args, in_dir)
+            utils.runscript(script, args, in_dir)
 
             baseinfile = os.path.basename(infilename)
             assert os.path.exists(os.path.join(in_dir, baseinfile + '.part'))
@@ -666,7 +732,7 @@ def _DEBUG_make_graph(infilename, min_hashsize=1e7, n_hashes=2, ksize=20,
 
     args.extend([outfile, infile])
 
-    runscript(script, args)
+    utils.runscript(script, args)
 
     ht_file = outfile + '.ct'
     assert os.path.exists(ht_file), ht_file
@@ -680,12 +746,12 @@ def _DEBUG_make_graph(infilename, min_hashsize=1e7, n_hashes=2, ksize=20,
         args = [outfile]
         if stop_big_traverse:
             args.insert(0, '--no-big-traverse')
-        runscript(script, args)
+        utils.runscript(script, args)
 
         print ">>>> DEBUG: Merging Partitions <<<"
         script = scriptpath('merge-partitions.py')
         args = [outfile, '-k', str(ksize)]
-        runscript(script, args)
+        utils.runscript(script, args)
 
         final_pmap_file = outfile + '.pmap.merged'
         assert os.path.exists(final_pmap_file)
@@ -696,7 +762,7 @@ def _DEBUG_make_graph(infilename, min_hashsize=1e7, n_hashes=2, ksize=20,
             args = ["-k", str(ksize), outfile, infilename]
 
             in_dir = os.path.dirname(outfile)
-            runscript(script, args, in_dir)
+            utils.runscript(script, args, in_dir)
 
             baseinfile = os.path.basename(infilename)
             assert os.path.exists(os.path.join(in_dir, baseinfile + '.part'))
@@ -710,11 +776,11 @@ def test_partition_graph_1():
     script = scriptpath('partition-graph.py')
     args = [graphbase]
 
-    runscript(script, args)
+    utils.runscript(script, args)
 
     script = scriptpath('merge-partitions.py')
     args = [graphbase, '-k', str(20)]
-    runscript(script, args)
+    utils.runscript(script, args)
 
     final_pmap_file = graphbase + '.pmap.merged'
     assert os.path.exists(final_pmap_file)
@@ -734,11 +800,11 @@ def test_partition_graph_nojoin_k21():
     script = scriptpath('partition-graph.py')
     args = [graphbase]
 
-    runscript(script, args)
+    utils.runscript(script, args)
 
     script = scriptpath('merge-partitions.py')
     args = [graphbase, '-k', str(21)]
-    runscript(script, args)
+    utils.runscript(script, args)
 
     final_pmap_file = graphbase + '.pmap.merged'
     assert os.path.exists(final_pmap_file)
@@ -766,11 +832,11 @@ def test_partition_graph_nojoin_stoptags():
     script = scriptpath('partition-graph.py')
     args = ['--stoptags', stoptags_file, graphbase]
 
-    runscript(script, args)
+    utils.runscript(script, args)
 
     script = scriptpath('merge-partitions.py')
     args = [graphbase, '-k', str(20)]
-    runscript(script, args)
+    utils.runscript(script, args)
 
     final_pmap_file = graphbase + '.pmap.merged'
     assert os.path.exists(final_pmap_file)
@@ -825,7 +891,7 @@ def test_annotate_partitions():
 
     script = scriptpath('annotate-partitions.py')
     args = ["-k", "20", graphbase, seqfile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     partfile = os.path.join(in_dir, 'random-20-a.fa.part')
 
@@ -848,7 +914,7 @@ def test_annotate_partitions_2():
 
     script = scriptpath('annotate-partitions.py')
     args = ["-k", "21", graphbase, seqfile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     partfile = os.path.join(in_dir, 'random-20-a.fa.part')
 
@@ -871,7 +937,7 @@ def test_extract_partitions():
     script = scriptpath('extract-partitions.py')
     args = ['extracted', partfile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     distfile = os.path.join(in_dir, 'extracted.dist')
     groupfile = os.path.join(in_dir, 'extracted.group0000.fa')
@@ -900,7 +966,7 @@ def test_extract_partitions_fq():
     script = scriptpath('extract-partitions.py')
     args = ['extracted', partfile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     distfile = os.path.join(in_dir, 'extracted.dist')
     groupfile = os.path.join(in_dir, 'extracted.group0000.fq')
@@ -933,7 +999,7 @@ def test_extract_partitions_output_unassigned():
     script = scriptpath('extract-partitions.py')
     args = ['-U', 'extracted', partfile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     distfile = os.path.join(in_dir, 'extracted.dist')
     groupfile = os.path.join(in_dir, 'extracted.group0000.fa')
@@ -965,7 +1031,7 @@ def test_extract_partitions_no_output_groups():
     args = ['-n', 'extracted', partfile]
 
     # We expect a sys.exit -> we need the test to be tolerant
-    runscript(script, args, in_dir, fail_ok=True)
+    utils.runscript(script, args, in_dir, fail_ok=True)
 
     # Group files are created after output_groups is
     # checked. They should not exist in this scenario
@@ -983,7 +1049,7 @@ def test_extract_partitions_pid_0():
     script = scriptpath('extract-partitions.py')
     args = ['-U', 'extracted', partfile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     distfile = os.path.join(in_dir, 'extracted.dist')
     groupfile = os.path.join(in_dir, 'extracted.group0000.fa')
@@ -1008,7 +1074,7 @@ def test_extract_partitions_multi_groups():
     script = scriptpath('extract-partitions.py')
     args = ['-m', '1', '-X', '1', 'extracted', partfile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     # Multiple group files are created after should be created
     groupfile1 = os.path.join(in_dir, 'extracted.group0000.fa')
@@ -1030,7 +1096,7 @@ def test_extract_partitions_no_groups():
     script = scriptpath('extract-partitions.py')
     args = ['extracted', empty_file]
 
-    runscript(script, args, in_dir, fail_ok=True)
+    utils.runscript(script, args, in_dir, fail_ok=True)
 
     # No group files should be created
     groupfile = os.path.join(in_dir, 'extracted.group0000.fa')
@@ -1049,7 +1115,7 @@ def test_abundance_dist():
 
     script = scriptpath('abundance-dist.py')
     args = ['-z', htfile, infile, outfile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     fp = iter(open(outfile))
     line = fp.next().strip()
@@ -1069,7 +1135,7 @@ def test_abundance_dist_nobigcount():
 
     script = scriptpath('abundance-dist.py')
     args = ['-z', htfile, infile, outfile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     fp = iter(open(outfile))
     line = fp.next().strip()
@@ -1088,9 +1154,9 @@ def test_abundance_dist_single():
     script = scriptpath('abundance-dist-single.py')
     args = ['-x', '1e7', '-N', '2', '-k', '17', '-z', '-t', infile,
             outfile]
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
 
-    assert 'Total number of k-mers: 98' in err, err
+    assert 'Total number of unique k-mers: 98' in err, err
 
     fp = iter(open(outfile))
     line = fp.next().strip()
@@ -1108,7 +1174,7 @@ def test_abundance_dist_single_nobigcount():
 
     script = scriptpath('abundance-dist-single.py')
     args = ['-x', '1e7', '-N', '2', '-k', '17', '-z', '-b', infile, outfile]
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     fp = iter(open(outfile))
     line = fp.next().strip()
@@ -1125,7 +1191,7 @@ def test_do_partition():
     script = scriptpath('do-partition.py')
     args = ["-k", "20", graphbase, seqfile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     partfile = os.path.join(in_dir, 'random-20-a.fa.part')
 
@@ -1144,7 +1210,7 @@ def test_do_partition_2():
     script = scriptpath('do-partition.py')
     args = ["-k", "21", graphbase, seqfile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     partfile = os.path.join(in_dir, 'random-20-a.fa.part')
 
@@ -1170,7 +1236,7 @@ def test_interleave_reads_1_fq():
     script = scriptpath('interleave-reads.py')
     args = [infile1, infile2, '-o', outfile]
 
-    runscript(script, args)
+    utils.runscript(script, args)
 
     r = open(ex_outfile).read()
     q = open(outfile).read()
@@ -1192,7 +1258,7 @@ def test_interleave_reads_2_fa():
     script = scriptpath('interleave-reads.py')
     args = [infile1, infile2, '-o', outfile]
 
-    runscript(script, args)
+    utils.runscript(script, args)
 
     n = 0
     for r, q in zip(screed.open(ex_outfile), screed.open(outfile)):
@@ -1202,6 +1268,38 @@ def test_interleave_reads_2_fa():
     assert n > 0
 
 
+def test_make_initial_stoptags():
+    # gen input files using load-graph.py -t
+    # should keep test_data directory size down
+    # or something like that
+    # this assumes (obv.) load-graph works properly
+    bzinfile = utils.get_temp_filename('test-reads.fq.bz2')
+    shutil.copyfile(utils.get_test_data('test-reads.fq.bz2'), bzinfile)
+    in_dir = os.path.dirname(bzinfile)
+
+    genscript = scriptpath('load-graph.py')
+    genscriptargs = ['-t', 'test-reads', 'test-reads.fq.bz2']
+    utils.runscript(genscript, genscriptargs, in_dir)
+
+    # test input file gen'd by load-graphs
+    infile = utils.get_temp_filename('test-reads.pt')
+    infile2 = utils.get_temp_filename('test-reads.tagset', in_dir)
+
+    # get file to compare against
+    ex_outfile = utils.get_test_data('test-reads.stoptags')
+
+    # actual output file
+    outfile1 = utils.get_temp_filename('test-reads.stoptags', in_dir)
+
+    script = scriptpath('make-initial-stoptags.py')
+    # make-initial-stoptags has weird file argument syntax
+    # read the code before modifying
+    args = ['test-reads']
+
+    utils.runscript(script, args, in_dir)
+    assert os.path.exists(outfile1), outfile1
+
+
 def test_extract_paired_reads_1_fa():
     # test input file
     infile = utils.get_test_data('paired-mixed.fa')
@@ -1217,7 +1315,7 @@ def test_extract_paired_reads_1_fa():
     script = scriptpath('extract-paired-reads.py')
     args = [infile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     assert os.path.exists(outfile1), outfile1
     assert os.path.exists(outfile2), outfile2
@@ -1252,7 +1350,7 @@ def test_extract_paired_reads_2_fq():
     script = scriptpath('extract-paired-reads.py')
     args = [infile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     assert os.path.exists(outfile1), outfile1
     assert os.path.exists(outfile2), outfile2
@@ -1289,7 +1387,7 @@ def test_split_paired_reads_1_fa():
     script = scriptpath('split-paired-reads.py')
     args = [infile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     assert os.path.exists(outfile1), outfile1
     assert os.path.exists(outfile2), outfile2
@@ -1324,7 +1422,7 @@ def test_split_paired_reads_2_fq():
     script = scriptpath('split-paired-reads.py')
     args = [infile]
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     assert os.path.exists(outfile1), outfile1
     assert os.path.exists(outfile2), outfile2
@@ -1356,7 +1454,7 @@ def test_sample_reads_randomly():
     # fix random number seed for reproducibility
     args = ['-N', '10', '-R', '1']
     args.append(infile)
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.subset'
     assert os.path.exists(outfile), outfile
@@ -1385,32 +1483,32 @@ def test_fastq_to_fasta():
     in_dir_n = os.path.dirname(n_infile)
 
     args = [clean_infile, '-n', '-o', clean_outfile]
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
     assert len(out.splitlines()) == 2, len(out.splitlines())
     assert "No lines dropped" in err
 
     args = [n_infile, '-n', '-o', n_outfile]
-    (status, out, err) = runscript(script, args, in_dir_n)
+    (status, out, err) = utils.runscript(script, args, in_dir_n)
     assert len(out.splitlines()) == 2
     assert "No lines dropped" in err
 
     args = [clean_infile, '-o', clean_outfile]
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
     assert len(out.splitlines()) == 2
     assert "0 lines dropped" in err
 
     args = [n_infile, '-o', n_outfile]
-    (status, out, err) = runscript(script, args, in_dir_n)
+    (status, out, err) = utils.runscript(script, args, in_dir_n)
     assert len(out.splitlines()) == 2, out
     assert "4 lines dropped" in err, err
 
     args = [clean_infile]
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
     assert len(out.splitlines()) > 2
     assert "0 lines dropped" in err
 
     args = [n_infile]
-    (status, out, err) = runscript(script, args, in_dir_n)
+    (status, out, err) = utils.runscript(script, args, in_dir_n)
     assert len(out.splitlines()) > 2
     assert "4 lines dropped" in err
 
@@ -1431,13 +1529,13 @@ def test_extract_long_sequences():
     in_dir_fa = os.path.dirname(fa_infile)
 
     args = [fq_infile, '-l', '10', '-o', 'fq_outfile']
-    (status, out, err) = runscript(script, args, in_dir_fa)
+    (status, out, err) = utils.runscript(script, args, in_dir_fa)
 
     countlines = sum(1 for line in open(fq_infile))
     assert countlines == 44, countlines
 
     args = [fa_infile, '-l', '10', '-o', 'fa_outfile']
-    (status, out, err) = runscript(script, args, in_dir_fa)
+    (status, out, err) = utils.runscript(script, args, in_dir_fa)
 
     countlines = sum(1 for line in open(fa_infile))
     assert countlines == 22, countlines
@@ -1456,12 +1554,12 @@ def test_sample_reads_randomly_S():
 
     badargs = list(args)
     badargs.extend(['-o', 'test', 'test.fq', 'test.fq'])
-    (status, out, err) = runscript(script, badargs, in_dir, fail_ok=True)
+    (status, out, err) = utils.runscript(script, badargs, in_dir, fail_ok=True)
     assert status == -1, (status, out, err)
 
     args.append('test.fq')
 
-    runscript(script, args, in_dir)
+    utils.runscript(script, args, in_dir)
 
     outfile = infile + '.subset.0'
     assert os.path.exists(outfile), outfile
@@ -1509,7 +1607,7 @@ def test_count_overlap():
     script = scriptpath('count-overlap.py')
     args = ['--ksize', '20', '--n_tables', '2', '--min-tablesize', '10000000',
             htfile + '.pt', seqfile2, outfile]
-    (status, out, err) = runscript(script, args, in_dir)
+    (status, out, err) = utils.runscript(script, args, in_dir)
     assert status == 0
     assert os.path.exists(outfile), outfile
     data = [x.strip() for x in open(outfile)]
@@ -1522,3 +1620,176 @@ def test_count_overlap():
     assert '178633 1155' in data
     assert '496285 2970' in data
     assert '752053 238627' in data
+
+
+def execute_streaming_diginorm(ifilename):
+    '''Helper function for the matrix of streaming tests for read_parser
+    using diginorm, i.e. uncompressed fasta, gzip fasta, bz2 fasta,
+    uncompressed fastq, etc.
+    This is not directly executed but is run by the tests themselves
+    '''
+    # Get temp filenames, etc.
+    fifo = utils.get_temp_filename('fifo')
+    in_dir = os.path.dirname(fifo)
+    script = scriptpath('normalize-by-median.py')
+    args = ['-C', '1', '-k', '17', '-o', 'outfile', fifo]
+
+    # make a fifo to simulate streaming
+    os.mkfifo(fifo)
+
+    # FIFOs MUST BE OPENED FOR READING BEFORE THEY ARE WRITTEN TO
+    # If this isn't done, they will BLOCK and things will hang.
+    thread = threading.Thread(target=utils.runscript,
+                              args=(script, args, in_dir))
+    thread.start()
+    ifile = io.open(ifilename, 'rb')
+    fifofile = io.open(fifo, 'wb')
+    # read binary to handle compressed files
+    chunk = ifile.read(8192)
+    while len(chunk) > 0:
+        fifofile.write(chunk)
+        chunk = ifile.read(8192)
+
+    fifofile.close()
+
+    thread.join()
+
+    return in_dir + '/outfile'
+
+
+def execute_abund_dist_single_streaming(ifilename, somedir=None):
+    '''Helper function for the matrix of streaming tests using screed via
+    filter-abund-single, i.e. uncompressed fasta, gzip fasta, bz2 fasta,
+    uncompressed fastq, etc.
+    This is not directly executed but is run by the tests themselves
+    '''
+
+    fifo = utils.get_temp_filename('fifo')
+    in_dir = os.path.dirname(fifo)
+    ifile = open(ifilename, 'rb')
+    script = scriptpath('abundance-dist-single.py')
+    args = ['-x', '1e7', '-N', '2', '-k', '6', '-t', fifo, 'outfile']
+    os.mkfifo(fifo)
+
+    thread = threading.Thread(target=utils.runscript,
+                              args=(script, args, in_dir))
+    thread.start()
+
+    fifofile = open(fifo, 'wb')
+    chunk = ifile.read(8192)
+    while len(chunk) > 0:
+        fifofile.write(chunk)
+        chunk = ifile.read(8192)
+
+    fifofile.close()
+    thread.join()
+
+    return in_dir + '/outfile'
+
+
+@attr('known_failing')
+def test_screed_streaming_ufa():
+    # uncompressed fa
+    o = execute_streaming_diginorm(utils.get_test_data('test-abund-read-2.fa'))
+
+    pathstat = os.stat(o)
+    seqs = [r.sequence for r in screed.open(o)]
+    assert len(seqs) == 1, seqs
+    assert seqs[0].startswith('GGTTGACGGGGCTCAGGGGG')
+
+
+@attr('known_failing')
+def test_screed_streaming_ufq():
+    # uncompressed fq
+    o = execute_streaming_diginorm(utils.get_test_data('test-fastq-reads.fq'))
+
+    seqs = [r.sequence for r in screed.open(o)]
+    assert seqs[0].startswith('CAGGCGCCCACCACCGTGCCCTCCAACCTGATGGT')
+
+
+@attr('known_failing')
+def test_screed_streaming_bzipfq():
+    # bzip compressed fq
+    o = execute_streaming_diginorm(utils.get_test_data('100-reads.fq.bz2'))
+    seqs = [r.sequence for r in screed.open(o)]
+    assert len(seqs) == 100, seqs
+    assert seqs[0].startswith('CAGGCGCCCACCACCGTGCCCTCCAACCTGATGGT'), seqs
+
+
+@attr('known_failing')
+def test_screed_streaming_bzipfa():
+    # bzip compressed fa
+    o = execute_streaming_diginorm(
+        utils.get_test_data('test-abund-read-2.fa.bz2'))
+
+    seqs = [r.sequence for r in screed.open(o)]
+    assert len(seqs) == 1, seqs
+    assert seqs[0].startswith('GGTTGACGGGGCTCAGGGGG')
+
+
+@attr('known_failing')
+def test_screed_streaming_gzipfq():
+    # gzip compressed fq
+    o = execute_streaming_diginorm(utils.get_test_data('100-reads.fq.gz'))
+    assert os.path.exists(o)
+    seqs = [r.sequence for r in screed.open(o)]
+    assert seqs[0].startswith('CAGGCGCCCACCACCGTGCCCTCCAACCTG')
+
+
+@attr('known_failing')
+def test_screed_streaming_gzipfa():
+    o = execute_streaming_diginorm(
+        utils.get_test_data('test-abund-read-2.fa.gz'))
+    assert os.path.exists(o)
+    seqs = [r.sequence for r in screed.open(o)]
+    assert seqs[0].startswith('GGTTGACGGGGCTCAGGGG')
+
+
+@attr('known_failing')
+def test_read_parser_streaming_ufa():
+    # uncompressed fa
+    o = execute_abund_dist_single_streaming(
+        utils.get_test_data('test-abund-read-2.fa'))
+    assert os.path.exists(o)
+    seqs = [r.sequence for r in screed.open(o)]
+    assert seqs[0].startswith('GGTTGACGGGGCTCAGGGG')
+
+
+@attr('known_failing')
+def test_read_parser_streaming_bzfq():
+    # bzip compressed
+    o = execute_abund_dist_single_streaming(
+        utils.get_test_data('100-reads.fq.bz2'))
+    assert os.path.exists(o)
+    seqs = [r.sequence for r in screed.open(o)]
+    assert seqs[0].startswith('CAGGCGCCCACCACCGTGCCCTCCAACCTG')
+
+
+@attr('known_failing')
+def test_read_parser_streaming_gzfq():
+    # bzip compressed
+    o = execute_abund_dist_single_streaming(
+        utils.get_test_data('100-reads.fq.gz'))
+    assert os.path.exists(o)
+    seqs = [r.sequence for r in screed.open(o)]
+    assert seqs[0].startswith('CAGGCGCCCACCACCGTGCCCTCCAACCTG')
+
+
+@attr('known_failing')
+def test_read_parser_streaming_bzfa():
+    # bzip compressed
+    o = execute_abund_dist_single_streaming(
+        utils.get_test_data('test-abund-read-2.fa.bz2'))
+    assert os.path.exists(o)
+    seqs = [r.sequence for r in screed.open(o)]
+    assert seqs[0].startswith('GGTTGACGGGGCTCAGGGG')
+
+
+@attr('known_failing')
+def test_read_parser_streaming_gzfa():
+    # bzip compressed
+    o = execute_abund_dist_single_streaming(
+        utils.get_test_data('test-abund-read-2.fa.gz'))
+    assert os.path.exists(o)
+    seqs = [r.sequence for r in screed.open(o)]
+    assert seqs[0].startswith('GGTTGACGGGGCTCAGGGG')
